.. aif360-bias-toolbox documentation master file, created by
   sphinx-quickstart on Fri Jun  8 14:05:59 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

AI Fairness 360 documentation
=============================

.. toctree::
   :maxdepth: 1

   Getting Started
   CONTRIBUTING

.. toctree::
   :maxdepth: 2
   :caption: Modules

   modules/algorithms
   modules/datasets
   modules/explainers
   modules/metrics

.. toctree::
   :maxdepth: 3

   modules/sklearn


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
